# ProSPr
## The Protein Structure Prediction Toolbox
**Author:** Okke van Eck  
**Version:** 0.1a7

This project is an universal toolbox for protein structure prediction within the HP-model.
It will contain a datastructure for creating own algorithms, pre-created algorithms, datasets and visualization functions.
Besides folding proteins, this package will also make it possible to determine the relative hardness of a protein for an algorithm.
This allows for a fair comparison across the different algorithms.

So far, only square lattices are supported in n-dimensions.
The amino acids can only be placed in the corners of the squares and have to be one unit away from the previously placed amino acid.

## Installation guide
This package can simply be installed via pip by running:
```bash
pip install prospr
```

## Example usage
*Work in progress*

## Future work
This toolbox could be used for other protein folding problems within discrete models.
It would be a great extension to support different models by creating a modular amino acid. 

## Changelog
*Work in progress*

## License
The used license is the GNU LESSER GENERAL PUBLIC LICENSE.
A copy can be found in the [LICENSE](LICENSE) file on GitHub.
